RCLADE_X_MIN_FLOOR: Minimum x-axis value used when the tree root reaches into the...

RCLADE_X_MIN_FLOORR Documentation

Minimum x-axis value used when the tree root reaches into the Hadean (4567–4031 Ma), so the full Hadean eon is visible in that case

Description

Minimum x-axis value used when the tree root reaches into the Hadean (4567–4031 Ma), so the full Hadean eon is visible in that case

Usage

RCLADE_X_MIN_FLOOR

Rclade documentation built on Sept. 26, 2026, 5:07 p.m.