example_tree: Example phylogenetic tree with GTDB-style labels

example_treeR Documentation

Example phylogenetic tree with GTDB-style labels

Description

A phylo object with 50 tips containing GTDB-format taxonomic labels spanning 5 coded phyla (P1, P2, P3, P4, P5) and 10 coded classes (C1, ..., C10) for demonstration and testing purposes. Branch lengths are in Ma (mega-annum). This tree is fully bifurcating with proper monophyletic groups at all taxonomic levels. All labels are artificial codes, not real taxon names.

Usage

data(example_tree)

Format

A phylo object with 50 tips and 49 internal nodes.

Simulated data for package demonstration.


Rclade documentation built on Sept. 26, 2026, 5:07 p.m.