get_git_hash: Get the current git short hash of the installed package...

View source: R/params-helpers.R

get_git_hashR Documentation

Get the current git short hash of the installed package source

Description

Consolidates the previously duplicated git-hash detection found in cli.R::get_version_string() and logo.R::rclade_logo(). Returns "unknown" when not running from a git working tree or when git is unavailable / errors.

Usage

get_git_hash()

Value

Character: short git hash (7 chars) or "unknown".


Rclade documentation built on Sept. 26, 2026, 5:07 p.m.