| RCLADE_X_MIN_FLOOR | R Documentation |
Minimum x-axis value used when the tree root reaches into the Hadean (4567–4031 Ma), so the full Hadean eon is visible in that case
RCLADE_X_MIN_FLOOR
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.