| batch_with_interrupt | R Documentation |
Processes a list of items with progress tracking and graceful interrupt handling. If interrupted, reports how many items were completed before stopping.
batch_with_interrupt(items, fun, label_fun = NULL)
items |
List or vector of items to process. |
fun |
Function to apply to each item. Receives (item, index). |
label_fun |
Optional function to generate label for each item. |
List of results (NULL for items not processed due to interrupt).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.