View source: R/custom-groups.R
| build_group_vec | R Documentation |
Converts a named list of tip vectors into the named-vector format used
by compute_mrca_map().
build_group_vec(groups, tip_labels)
groups |
Named list of character vectors (tip labels per group). |
tip_labels |
Character vector of all tip labels in the tree. |
Named character vector: names = tip labels, values = group names,
NA for ungrouped tips.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.