View source: R/taxonomy-file.R
| build_taxonomy_lookup | R Documentation |
Creates a lookup table from a taxonomy file that can be used to supplement or override label-based taxonomy parsing.
build_taxonomy_lookup(file, sep = "auto", header = FALSE, table_sep = ";")
file |
Character. Path to the taxonomy table file. |
sep |
Character. Column separator. Default: |
header |
Logical. Whether the file has a header row. Default: |
table_sep |
Character. Separator between taxonomy ranks in the second
column. Default: |
A named list where names are tip labels and values are data.frame rows with taxonomy information.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.