View source: R/parse-taxonomy.R
| escape_regex | R Documentation |
Wraps every regex-metacharacter in a backslash so the resulting string can
be embedded literally in a pattern. Used by the semicolon-delimited parser
(and any other code that turns a user separator into a regex) so that a
separator such as "." or "+" is matched as a literal character
rather than as a metacharacter.
escape_regex(x)
x |
Character scalar to escape. |
Escaped character scalar.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.