| example_tree | R Documentation |
A phylo object with 50 tips containing GTDB-format taxonomic labels
spanning 5 coded phyla (P1, P2, P3, P4, P5) and 10 coded classes (C1, ..., C10)
for demonstration and testing purposes. Branch lengths are in Ma (mega-annum).
This tree is fully bifurcating with proper monophyletic groups at all
taxonomic levels. All labels are artificial codes, not real taxon names.
data(example_tree)
A phylo object with 50 tips and 49 internal nodes.
Simulated data for package demonstration.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.